@@ -45,6 +45,7 @@ function get_diag_commands {
         'iptables -vnL -t mangle'
         'ifconfig -a'
         'ip addr show'
+        'ip netns'
         'lsmod'
         'timeout 15 lsof' # High potential of getting stuck
         'lsof -Pni'
@@ -103,7 +104,7 @@ function get_config_and_logs {
         '/var/log/mariadb'
         '/etc/httpd/conf.d/'
         '/var/log/httpd'
-        '/var/tmp/packstack'
+        '/var/tmp/packstack/latest'
         '/var/tmp/packstack/latest/testrepository.subunit' # So we're copying it
         '/var/log/audit'                                   # to the root of
         '/var/log/secure'                                  # /logs
@@ -149,12 +150,6 @@ function ensure_log_properties {
             $SUDO mv ${file} ${file}.txt
         fi
     done
-
-    echo "Compressing all text files..."
-    # Compress all files
-    $FIND -iname '*.txt' -execdir gzip -f -9 {} \+
-
-    echo "Compressed log and configuration can be found in ${LOGDIR}."
 }
 
 function recover_default_logs {
